==> cold_1.0-1.tar.gz: cold/man/summary-methods.Rd <==
\name{summary-methods}
\docType{methods}
\alias{summary-methods}
\alias{summary,cold-method}
\title{Methods for Function summary in package "cold"}
\description{ Summarize objects}
\usage{
\S4method{summary}{cold}(object, cov=FALSE, cor=FALSE)}
\arguments{ 
  \item{object}{an object of class \code{\link[=cold-class]{cold}}.}
  \item{cov}{if set to TRUE prints the matrix of covariances between parameters estimates. The default is FALSE.}
  \item{cor}{if set to TRUE prints the matrix of correlations between parameters estimates. The default is FALSE.}  
   }  
\details{ Computes and returns a list of summary statistics of the fitted linear model given a \code{cold} object, 
using the components (list elements) "call" and "terms" from its argument, plus 
depending on the structure of the dependence model chosen, the table for the estimates of coefficients will appear 
\code{rho} if the dependence structure of the process corresponds to a AR1.
If the structure of the dependence model chosen includes the random intercept (models "\code{indR}" and "\code{AR1R}") 
the estimate of the random effect (\code{omega}) will also appear where \eqn{\omega=\log\sigma^2}{\omega=log(\omega^2)}.}
\section{Methods}{
\describe{
\item{\code{signature(object = "ANY")}:}{Generic function.}
\item{\code{signature(object = "cold")}:}{Generate a summary as an object of class 
\code{\link[=summary.cold-class]{summary.cold}}, 
containing information about the matched call to \code{cold}, the number of profiles in the data, 
the number of profiles used in the fit, the log-likelihood, the AIC,
a table with estimates, asymptotic SE, t-values and p-values,  
the estimated correlation and variance-covariance matrix for the estimated parameters if the user wishes, 
and a message giving additional information returned by the optimizer.}
}}
\keyword{methods}

==> cold_1.0-4.tar.gz: cold/man/summary-methods.Rd <==
\name{summary-methods}
\docType{methods}
\alias{summary-methods}
\alias{summary,cold-method}
\title{Methods for Function summary in Package "cold"}
\description{ Summarize objects}
\usage{
\S4method{summary}{cold}(object, cov=FALSE, cor=FALSE)}
\arguments{ 
  \item{object}{an object of class \code{\link[=cold-class]{cold}}.}
  \item{cov}{if set to TRUE prints the matrix of covariances between parameters estimates. The default is FALSE.}
  \item{cor}{if set to TRUE prints the matrix of correlations between parameters estimates. The default is FALSE.}  
   }  
\details{ Computes and returns a list of summary statistics of the fitted linear model given a \code{cold} object, 
using the components (list elements) "call" and "terms" from its argument, plus 
depending on the structure of the dependence model chosen, the table for the estimates of coefficients will appear 
\code{rho} if the dependence structure of the process corresponds to a AR1.
If the structure of the dependence model chosen includes the random intercept (models "\code{indR}" and "\code{AR1R}") 
the estimate of the random effect (\code{omega}) will also appear where \eqn{\omega=\log\sigma^2}{\omega=log(\omega^2)}.}
\section{Methods}{
\describe{
\item{\code{signature(object = "ANY")}:}{Generic function.}
\item{\code{signature(object = "cold")}:}{Prints a summary as an object of class 
\code{\link[=summary.cold-class]{summary.cold}}, 
containing information about the matched call to \code{cold}, the number of profiles in the data, 
the number of profiles used in the fit, the log-likelihood, the AIC,
a table with estimates, asymptotic SE, t-values and p-values,  
the estimated correlation and variance-covariance matrix for the estimated parameters if the user wishes, 
and a message giving additional information returned by the optimizer.}
}}
\keyword{methods}
